@@ -397,7 +397,7 @@ Tab::LoadResult
 Tab::loadFromMatroskaFile(QString const &fileName,
                           bool append) {
   auto p        = p_func();
-  auto analyzer = std::make_unique<QtKaxAnalyzer>(this, fileName);
+  auto analyzer = std::make_unique<Util::KaxAnalyzer>(this, fileName);
 
   if (!analyzer->set_parse_mode(kax_analyzer_c::parse_mode_fast).set_open_mode(MODE_READ).process()) {
     auto text = Q("%1 %2")
@@ -830,7 +830,7 @@ Tab::saveToMatroskaImpl(bool requireNewFileName) {
     }
 
     if (doRequireNewFileName || (QFileInfo{newFileName}.lastModified() != p->fileModificationTime)) {
-      p->analyzer = std::make_unique<QtKaxAnalyzer>(this, newFileName);
+      p->analyzer = std::make_unique<Util::KaxAnalyzer>(this, newFileName);
       if (!p->analyzer->set_parse_mode(kax_analyzer_c::parse_mode_fast).process()) {
         auto text = Q("%1 %2")
           .arg(QY("The file you tried to open (%1) could not be read successfully.").arg(newFileName))
@@ -860,7 +860,7 @@ Tab::saveToMatroskaImpl(bool requireNewFileName) {
     p->analyzer->close_file();
 
     if (kax_analyzer_c::uer_success != result) {
-      QtKaxAnalyzer::displayUpdateElementResult(this, result, QY("Saving the chapters failed."));
+      Util::KaxAnalyzer::displayUpdateElementResult(this, result, QY("Saving the chapters failed."));
       return false;
     }
 
@@ -1271,26 +1271,18 @@ Tab::chapterNameLanguageChanged() {
     return;
   }
 
-  QSet<mtx::bcp47::language_c> uniqueLanguageCodes;
+  std::vector<mtx::bcp47::language_c> languageCodes;
 
   for (auto const &control : p.languageControls) {
     auto languageCode = static_cast<mtx::gui::Util::LanguageDisplayWidget *>(std::get<1>(control))->language();
     if (languageCode.is_valid())
-      uniqueLanguageCodes << languageCode;
+      languageCodes.emplace_back(languageCode);
   }
 
-  auto languageCodes = uniqueLanguageCodes.values();
   std::sort(languageCodes.begin(), languageCodes.end());
 
   withSelectedName([&p, &languageCodes](QModelIndex const &idx, KaxChapterDisplay &display) {
-    DeleteChildren<KaxChapterLanguage>(display);
-    DeleteChildren<KaxChapLanguageIETF>(display);
-
-    for (auto const &languageCode : languageCodes) {
-      AddEmptyChild<KaxChapLanguageIETF>(display).SetValue(languageCode.format());
-      if (languageCode.has_valid_iso639_code())
-        AddEmptyChild<KaxChapterLanguage>(display).SetValue(languageCode.get_iso639_alpha_3_code());
-    }
+    mtx::chapters::set_languages_in_display(display, languageCodes);
 
     p.nameModel->updateRow(idx.row());
   });
